
**********************************************************************************************************************************
********                                                                                                                          ************************
********       INCONSISTENCIES BETWEEN VARIABLES IN SCHOOL HEAD BOOKLET     ************************
********                                                                                                                          ************************
********                                                                                                                          ************************
**********************************************************************************************************************************
**********************************************************************************************************************************

************************************************************************************************************************************
*                                                                                                                                                                  *
*      SCHOOL HEAD AGE VERSUS NUMBER OF YEARS TEACHING                                                            *
*                                                                                                                                                                  *
************************************************************************************************************************************

GET
  FILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolHeadBooket\03_SHBK_XXX_S3_26SEPT2007.SAV'.


COMPUTE shbk_cas = $CASENUM .
VARIABLE LABEL shbk_cas 'School Head Booklet Case Number'.
FORMAT shbk_cas (F8.0).
EXECUTE .

COMPUTE tstart_tech = SAGE - SEXPTCH .
EXECUTE .

USE ALL.
COMPUTE filter_$=(tstart_tech < 20).
VARIABLE LABEL filter_$ 'tstart_tech < 20 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sage sexptch
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'Discrepancies between school head age and years teaching (SHBK#5 #8)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



************************************************************************************************************************************
*                                                                                                                                                                  *
*      SCHOOL HEAD NUMBER OF YEARS TEACHING VERSUS NUMBER OF YEARS AS SCHOOL HEAD     *
*                                                                                                                                                                  *
************************************************************************************************************************************

COMPUTE tstart_tech = SEXPALL - SEXPTCH.
EXECUTE .

USE ALL.
COMPUTE filter_$=(tstart_tech GE 0).
VARIABLE LABEL filter_$ 'tstart_tech =< 0 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sexptch sexpall
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'Discrepancies years teaching and years as school head (SHBK#8 #9)'
  /MISSING=VARIABLE
  /CELLS=COUNT .




**********************************************************************************************************************************
*                                                                                                                                                                *
*              DISCREPANCIES IN SPECIALIZED TRAINING ON MANAGEMENT (SHBK#10)                               *
*                                                                                                                                                                *
**********************************************************************************************************************************


USE ALL.
COMPUTE filter_$=(sqspec = 2 and (sqspecdy = 0 or missing(sqspecdy)) or (sqspec=1 or missing(sqspec)) and sqspecdy GE 1).
VARIABLE LABEL filter_$ 'Discrepancies in specialized training on management (SHBK#10)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sqspec sqspecdy
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Discrepancies in specialized training on management (SHBK#10)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



**********************************************************************************************************************************
*                                                                                                                                                                *
*              DISCREPANCIES IN SPECIALIZED TRAINING ON HEALTH (SHBK#11)                                          *
*                                                                                                                                                                *
**********************************************************************************************************************************
 
USE ALL.
COMPUTE filter_$=( sqhlth  = 2 and (sqhlthdy = 0 or missing(sqhlthdy)) or (sqhlth=1or missing(sqhlthdy)) and sqhlthdy GE 1).
VARIABLE LABEL filter_$ 'Discrepancies in specialized training on health (SHBK#11)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sqhlth sqhlthdy
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Discrepancies in specialized training on health (SHBK#11)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



**********************************************************************************************************************************
*                                                                                                                                                                *
*              MISSING OR ZERO TEACHING MINUTES (SHBK#13)                                                                   *
*                                                                                                                                                                *
**********************************************************************************************************************************
 
USE ALL.
COMPUTE filter_$=((missing(sminutes) or sminutes =0)).
VARIABLE LABEL filter_$ ='Zero teaching minutes or missing (SHBK#13)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sminutes
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Zero teaching minutes or missing (SHBK#13)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



**********************************************************************************************************************************
*                                                                                                                                                                *
*              SCHOOL HAS NO ELECTRICITY BUT HAS ELETRICAL APPLIANCES (SHBK#20)                          *
*                                                                                                                                                                *
**********************************************************************************************************************************
 
USE ALL.
COMPUTE filter_$=(( sres20 = 1 or missing(sres20)) and
 (sres23=2 or
  sres24=2 or
  sres25=2 or 
  sres26=2 or
  sres27=2 or
  sres28=2 or
  sres29=2 or
  sres30=2 or
  sres31=2 or
  sres32=2)).
VARIABLE LABEL filter_$ 'No electricity but have appliances requiring electricity (SHBK#19)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sres20 sres23 TO sres32
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'No electricity but have appliances requiring electricity (#18)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



*********************************************************************************************************************************************
*                                                                                                                                                                              *
*     SCHOOL HAS NO LIBRARY OR MISSING (SHBK#19.01) BUT DID NOT TICK "NO LIBRARY" IN SHBK#20              *
*                                                                                                                                                                              *
*********************************************************************************************************************************************
 
USE ALL.
COMPUTE filter_$=((sres01 = 1 or missing(sres01)) and sborrow ~= 1).
VARIABLE LABEL filter_$ 'No library or missing (SHBK#19.01) but did not tick "no library" in #20'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sres01 sborrow
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'No library or missing (SHBK#19.01) but did not tick "no library" in SHBK#20'
  /MISSING=VARIABLE
  /CELLS=COUNT .



*********************************************************************************************************************************************
*                                                                                                                                                                              *
*        SCHOOL HAS LIBRARY (SHBK#19.01) BUT "NO LIBRARY" OR MISSING IN SHBK#20                                      *
*                                                                                                                                                                              *
*********************************************************************************************************************************************
 
USE ALL.
COMPUTE filter_$=(sres01 = 2 and (sborrow= 1 or missing(sborrow))).
VARIABLE LABEL filter_$ 'Have library (SHBK#19.01) but no library or missing (SHBK#20) '.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school sres01 sborrow
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'Have library (SHBK#19.01) but no library or missing (SHBK#20)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



******************************************************************************************************************************************
*                                                                                                                                                                          *
*       BEST INFO (SHBK#29) WAS NOT TICKED BEFORE (SHBK#28).                                                                    *
*                                                                                                                                                                          *
******************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=(SHINFOBT =  1 and  SHINFO01  ~= 2 or
  SHINFOBT =  2 and  SHINFO02 ~= 2 or
  SHINFOBT =  3 and  SHINFO03 ~= 2 or
  SHINFOBT =  4 and  SHINFO04 ~= 2 or
  SHINFOBT =  5 and  SHINFO05 ~= 2 or
  SHINFOBT =  6 and  SHINFO06 ~= 2 or
  SHINFOBT =  7 and  SHINFO07 ~= 2 or
  SHINFOBT =  8 and  SHINFO08 ~= 2 or
  SHINFOBT =  9 and  SHINFO09 ~= 2 or
  SHINFOBT =  10 and  SHINFO10 ~= 2 or
  SHINFOBT =  11 and  SHINFO11 ~= 2 or
  SHINFOBT =  12 and  SHINFO12 ~= 2 or
  SHINFOBT =  13 and  SHINFO13 ~= 2 or
  SHINFOBT =  14 and  SHINFO14 ~= 2 or
  SHINFOBT =  15 and  SHINFO15 ~= 2 or
  SHINFOBT =  16 and  SHINFO16 ~= 2 or
  SHINFOBT =  17 and  SHINFO17 ~= 2 or
  SHINFOBT =  18 and  SHINFO18 ~= 2 or
  SHINFOBT =  19 and  SHINFO19 ~= 2 or
  SHINFOBT =  20 and  SHINFO20 ~= 2 or 
  SHINFOBT =  21 and  SHINFO21 ~= 2 or 
  SHINFOBT =  22 and  SHINFO22 ~= 2 or 
  SHINFOBT =  23 and  SHINFO23 ~= 2 or 
  SHINFOBT =  24 and  SHINFO24 ~= 2 ).
VARIABLE LABEL filter_$ 'Best information source was not ticked before'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .


SUMMARIZE
  /TABLES=shbk_cas region district school SHINFOBT  SHINFO01 TO SHINFO24 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'The best information (SHBK#29) was not ticked before (SHBK#28)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



***************************************************************************************************************************************************
*                                                                                                                                                                                     *
*      DID NOT RECEIVE INFO FROM HIV PERSON (SHBK#28.23) BUT LATER SAID PERSON GAVE TALK (SHBK#33.07)   *
*                                                                                                                                                                                      *
***************************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=(shinfo23 = 1 and shcrs07 = 2).
VARIABLE LABEL filter_$ 'HIV person gave talk (SHBK#33.07) but no information from HIV person (SHBK#28.23)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school shinfo23 shcrs07 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'HIV person gave talk (SHBK#33.07) but no information from HIV person (SHBK#28.23)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



******************************************************************************************************************************************
*                                                                                                                                                                           *
* DID NOT RECEIVE INFO FROM HOSPITAL (SHBK#28.15) BUT LATER SAID VISITED HOSPITAL (SHBK#33.09)      *
*                                                                                                                                                                           *
******************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=(shinfo15 = 1 and shcrs09 = 2).
VARIABLE LABEL filter_$ 'Visited hospital but no info from hospital'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school shinfo15 shcrs09 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'Visited hospital (SHBK#28.15) but no info from hospital (SHBK#33.09)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



******************************************************************************************************************************************************************
*                                                                                                                                                                                                        *
*  DID NOT RECEIVE INFO VIDEO OR CINEMA (SHBK#28.03 & SHBK#28.10) BUT LATER SAID WATCHED VIDEO/FILM (SHBK#33.04)  *
*                                                                                                                                                                                                         *
******************************************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=((shinfo03 = 1 and shinfo10 = 1) and shcrs04 = 2).
VARIABLE LABEL filter_$ 'Watched video or film (SHBK#33.04) but no information from video or cinema (SHBK#28.03 & 28.10)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school shinfo03 shinfo10 shcrs04 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'Watched video or film (SHBK#33.04) but no information from video or cinema (SHBK#28.03 & 28.10)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



********************************************************************************************************************************************************************
*                                                                                                                                                                                                           *
* ATTENDED HIV IN-SERVICE COURSES (SHBK#32) BUT HAD SAID DID NOT GET INFO FROM IN-SERVICE TRAINING (SHBK#28.14)     *
*                                                                                                                                                                                                           *
********************************************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=(shcrshiv GE 2 and shinfo14 = 1).
VARIABLE LABEL filter_$ 'Attended HIV in-service courses (SHBK#32) but had said did not get HIV info from in-service training (SHBK#28.14)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school shcrshiv shinfo14
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'Attended HIV in-service courses (SHBK#32) but had said did not get HIV info from in-service training (SHBK#28.14)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



******************************************************************************************************************************************
*                                                                                                                                                                          *
* HAVE NOT ATTENDED IN-SERVICE COURSE ON HIV (SHBK#32) BUT ACTIVITY TICKED (SHBK#33).                  *
*                                                                                                                                                                          *
******************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=((SHCRSHIV = 0 or missing(SHCRSHIV)) and
 (SHCRS01 <= 2 or
  SHCRS02 <= 2 or   
  SHCRS03 <= 2 or   
  SHCRS04 <= 2 or   
  SHCRS05 <= 2 or   
  SHCRS06 <= 2 or   
  SHCRS07 <= 2 or   
  SHCRS08 <= 2 or   
  SHCRS09 <= 2 or   
  SHCRS10 <= 2 or   
  SHCRS11 <= 2 or   
  SHCRS12 <= 2 or   
  SHCRS13 <= 2 or   
  SHCRS14 <= 2 )).
VARIABLE LABEL filter_$ 'No in-service HIV course but at least one activity was responded (SHBK#33)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school SHCRSHIV SHCRS01 TO SHCRS14
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'No in-service HIV course but at least one activity was responded (SHBK#33)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



******************************************************************************************************************************************
*                                                                                                                                                                          *
* HAVE ATTENDED IN-SERVICE COURSE ON HIV (SHBK#32) BUT ALL ACTIVITY TICKED 'NO' OR MISSING (SHBK#33).
*                                                                                                                                                                          *
******************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=( (SHCRSHIV GE 1) and
  (SHCRS01 = 1 or missing(SHCRS01)) and
  (SHCRS02 = 1 or missing(SHCRS02)) and
  (SHCRS03 = 1 or missing(SHCRS03)) and
  (SHCRS04 = 1 or missing(SHCRS04)) and
  (SHCRS05 = 1 or missing(SHCRS05)) and
  (SHCRS06 = 1 or missing(SHCRS06)) and
  (SHCRS07 = 1 or missing(SHCRS07)) and
  (SHCRS08 = 1 or missing(SHCRS08)) and
  (SHCRS09 = 1 or missing(SHCRS09)) and
  (SHCRS10 = 1 or missing(SHCRS10)) and
  (SHCRS11 = 1 or missing(SHCRS11)) and
  (SHCRS12 = 1 or missing(SHCRS12)) and
  (SHCRS13 = 1 or missing(SHCRS13)) and
  (SHCRS14 = 1 or missing(SHCRS14)) ).
VARIABLE LABEL filter_$ 'Attended in-service HIV course but ticked no to all activities (SHBK#33)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school SHCRSHIV SHCRS01 TO SHCRS14
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'Attended in-service HIV course but ticked no to all activities (SHBK#33)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



******************************************************************************************************************************************
*                                                                                                                                                                          *
* HAVE NOT SPECIALIZED TRAINING ON HIV (SHBK#11) BUT ACTIVITY TICKED (SHBK#33).                                 *
*                                                                                                                                                                          *
******************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=((SQHLTH = 1 or missing(SQHLTH)) and
 (SHCRS01 <= 2 or
  SHCRS02 <= 2 or   
  SHCRS03 <= 2 or   
  SHCRS04 <= 2 or   
  SHCRS05 <= 2 or   
  SHCRS06 <= 2 or   
  SHCRS07 <= 2 or   
  SHCRS08 <= 2 or   
  SHCRS09 <= 2 or   
  SHCRS10 <= 2 or   
  SHCRS11 <= 2 or   
  SHCRS12 <= 2 or   
  SHCRS13 <= 2 or   
  SHCRS14 <= 2 )).
VARIABLE LABEL filter_$ 'No specialized training on HIV but at least one activity was responded (SHBK#33)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school SQHLTH SHCRS01 TO SHCRS14
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'No in-service HIV course but at least one activity was responded (SHBK#33)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



******************************************************************************************************************************************
*                                                                                                                                                                          *
*   BEST COURSE (SHBK#34) WAS NOT TICKED BEFORE (SHBK#33).                                                                 *
*                                                                                                                                                                          *
******************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=(shcrsbt =  1 and  shcrs01  ~= 2 or
  shcrsbt =  2 and  shcrs02  ~= 2 or
  shcrsbt =  3 and  shcrs03  ~= 2 or
  shcrsbt =  4 and  shcrs04  ~= 2 or
  shcrsbt =  5 and  shcrs05  ~= 2 or
  shcrsbt =  6 and  shcrs06  ~= 2 or
  shcrsbt =  7 and  shcrs07  ~= 2 or
  shcrsbt =  8 and  shcrs08  ~= 2 or
  shcrsbt =  9 and  shcrs09  ~= 2 or
  shcrsbt =  10 and  shcrs10  ~= 2 or
  shcrsbt =  11 and  shcrs11  ~= 2 or
  shcrsbt =  12 and  shcrs12  ~= 2 or
  shcrsbt =  13 and  shcrs13  ~= 2 or
  shcrsbt =  14 and  shcrs14  ~= 2   ).
VARIABLE LABEL filter_$ 'Best information course was not ticked before'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school SHCRSBT shcrs01 TO shcrs14  
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= 'The best course (SHBK#33) was not ticked before (SHBK#34)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



*******************************************************************************************************************************************************************************
*                                                                                                                                                                                                                        *
*   "NO" WAS TICKED FOR SUPPORT (OR MISSING) BUT AT LEAST ONE BOX UNDER "WITH THE ASSISTANCE OF" WAS TICKED (SHBK#34)   *
*                                                                                                                                                                                                                        *
*******************************************************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=
  (SHIVP01A =  1 or missing(SHIVP01A)) and  (SHIVP01B  = 2 or SHIVP01C  = 2 or SHIVP01D  = 2 or SHIVP01E  = 2) or
  (SHIVP02A =  1 or missing(SHIVP02A)) and  (SHIVP02B  = 2 or SHIVP02C  = 2 or SHIVP02D  = 2 or SHIVP02E  = 2) or
  (SHIVP03A =  1 or missing(SHIVP03A)) and  (SHIVP03B  = 2 or SHIVP03C  = 2 or SHIVP03D  = 2 or SHIVP03E  = 2) or
  (SHIVP04A =  1 or missing(SHIVP04A)) and  (SHIVP04B  = 2 or SHIVP04C  = 2 or SHIVP04D  = 2 or SHIVP04E  = 2) or
  (SHIVP05A =  1 or missing(SHIVP05A)) and  (SHIVP05B  = 2 or SHIVP05C  = 2 or SHIVP05D  = 2 or SHIVP05E  = 2) or
  (SHIVP06A =  1 or missing(SHIVP06A)) and  (SHIVP06B  = 2 or SHIVP06C  = 2 or SHIVP06D  = 2 or SHIVP06E  = 2) or
  (SHIVP07A =  1 or missing(SHIVP07A)) and  (SHIVP07B  = 2 or SHIVP07C  = 2 or SHIVP07D  = 2 or SHIVP07E  = 2) or
  (SHIVP08A =  1 or missing(SHIVP08A)) and  (SHIVP08B  = 2 or SHIVP08C  = 2 or SHIVP08D  = 2 or SHIVP08E  = 2) or
  (SHIVP09A =  1 or missing(SHIVP09A)) and  (SHIVP09B  = 2 or SHIVP09C  = 2 or SHIVP09D  = 2 or SHIVP09E  = 2) or
  (SHIVT10A =  1 or missing(SHIVT10A)) and  (SHIVT10B  = 2 or SHIVT10C  = 2 or SHIVT10D  = 2 or SHIVT10E  = 2) or
  (SHIVT11A =  1 or missing(SHIVT11A)) and  (SHIVT11B  = 2 or SHIVT11C  = 2 or SHIVT11D  = 2 or SHIVT11E  = 2) or
  (SHIVT12A =  1 or missing(SHIVT12A)) and  (SHIVT12B  = 2 or SHIVT12C  = 2 or SHIVT12D  = 2 or SHIVT12E  = 2) or
  (SHIVT13A =  1 or missing(SHIVT13A)) and  (SHIVT13B  = 2 or SHIVT13C  = 2 or SHIVT13D  = 2 or SHIVT13E  = 2) or
  (SHIVT14A =  1 or missing(SHIVT14A)) and  (SHIVT14B  = 2 or SHIVT14C  = 2 or SHIVT14D  = 2 or SHIVT14E  = 2) or
  (SHIVT15A =  1 or missing(SHIVT15A)) and  (SHIVT15B  = 2 or SHIVT15C  = 2 or SHIVT15D  = 2 or SHIVT15E  = 2)  .

VARIABLE LABEL filter_$ ' "No" was ticked for Support (or missing) but at least one box under "with the assistance of" was ticked (SHBK#34)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school SHIVP01A TO SHIVT15E
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= ' "No" was ticked for Support (or missing) but at least one box under "with the assistance of" was ticked (SHBK#34)'
  /MISSING=VARIABLE
  /CELLS=COUNT .



*************************************************************************************************************************************************************************************
*                                                                                                                                                                                                                                *
*   "YES" WAS TICKED FOR SUPPORT (OR MISSING) AND NONE OF THE BOXES UNDER "WITH THE ASSISTANCE OF" WERE TICKED (SHBK#34)   *
*                                                                                                                                                                                                                                 *
**************************************************************************************************************************************************************************************

USE ALL.
COMPUTE filter_$=
  (SHIVP01A =  2 or missing(SHIVP01A)) and  (SHIVP01B  ~= 2 OR SHIVP01C ~= 2 OR SHIVP01D  ~= 2 OR SHIVP01E  ~= 2) or
  (SHIVP02A =  2 or missing(SHIVP02A)) and  (SHIVP02B  ~= 2 or SHIVP02C  ~= 2 or SHIVP02D  ~= 2 or SHIVP02E  ~= 2) or
  (SHIVP03A =  2 or missing(SHIVP03A)) and  (SHIVP03B  ~= 2 or SHIVP03C  ~= 2 or SHIVP03D  ~= 2 or SHIVP03E  ~= 2) or
  (SHIVP04A =  2 or missing(SHIVP04A)) and  (SHIVP04B  ~= 2 or SHIVP04C  ~= 2 or SHIVP04D  ~= 2 or SHIVP04E  ~= 2) or
  (SHIVP05A =  2 or missing(SHIVP05A)) and  (SHIVP05B  ~= 2 or SHIVP05C  ~= 2 or SHIVP05D  ~= 2 or SHIVP05E  ~= 2) or
  (SHIVP06A =  2 or missing(SHIVP06A)) and  (SHIVP06B  ~= 2 or SHIVP06C  ~= 2 or SHIVP06D  ~= 2 or SHIVP06E  ~= 2) or
  (SHIVP07A =  2 or missing(SHIVP07A)) and  (SHIVP07B  ~= 2 or SHIVP07C  ~= 2 or SHIVP07D  ~= 2 or SHIVP07E  ~= 2) or
  (SHIVP08A =  2 or missing(SHIVP08A)) and  (SHIVP08B  ~= 2 or SHIVP08C  ~= 2 or SHIVP08D  ~= 2 or SHIVP08E  ~= 2) or
  (SHIVP09A =  2 or missing(SHIVP09A)) and  (SHIVP09B  ~= 2 or SHIVP09C  ~= 2 or SHIVP09D  ~= 2 or SHIVP09E  ~= 2) or
  (SHIVT10A =  2 or missing(SHIVT10A)) and  (SHIVT10B  ~= 2 or SHIVT10C  ~= 2 or SHIVT10D  ~= 2 or SHIVT10E  ~= 2) or
  (SHIVT11A =  2 or missing(SHIVT11A)) and  (SHIVT11B  ~= 2 or SHIVT11C  ~= 2 or SHIVT11D  ~= 2 or SHIVT11E  ~= 2) or
  (SHIVT12A =  2 or missing(SHIVT12A)) and  (SHIVT12B  ~= 2 or SHIVT12C  ~= 2 or SHIVT12D  ~= 2 or SHIVT12E  ~= 2) or
  (SHIVT13A =  2 or missing(SHIVT13A)) and  (SHIVT13B  ~= 2 or SHIVT13C  ~= 2 or SHIVT13D  ~= 2 or SHIVT13E  ~= 2) or
  (SHIVT14A =  2 or missing(SHIVT14A)) and  (SHIVT14B  ~= 2 or SHIVT14C  ~= 2 or SHIVT14D  ~= 2 or SHIVT14E  ~= 2) or
  (SHIVT15A =  2 or missing(SHIVT15A)) and  (SHIVT15B  ~= 2 or SHIVT15C  ~= 2 or SHIVT15D  ~= 2 or SHIVT15E  ~= 2)  .

VARIABLE LABEL filter_$ ' "Yes" was ticked for Support (or missing) and none of the boxes under "with the assistance of" were ticked (SHBK#34)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (F1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=shbk_cas region district school SHIVP01A TO SHIVT15E
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE= ' "Yes" was ticked for Support (or missing) and none of the boxes under "with the assistance of" were ticked (SHBK#34)'
  /MISSING=VARIABLE
  /CELLS=COUNT .


*************** END **************************** END *************************END ******************************* END ************************************************ .