
******************************************************************************************************************************************
********                                                                                                                                     ************************
********       CONSISTENCY CHECKS WITHIN SCHOOL FORM                                                   ************************
********                                                                                                                                     ************************
********                                                                                                                                     ************************
******************************************************************************************************************************************
******************************************************************************************************************************************

***********************************************************************************************************************************
*                                                                                                                                                                  *
*      CHECK FOR ENROLMENT                                                                                                                    *
*                                                                                                                                                                  *
************************************************************************************************************************************

GET
  FILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolForm\04_SF_XXX_S3_26SEPT2007.SAV'.

COMPUTE sf_cas = $CASENUM .
VARIABLE LABEL sf_cas 'School Form Case Number'.
FORMAT sf_cas (F8.0).
EXECUTE .


* Enrolment sub-sets and totals.
* Must be: sfnboy5 +sfngirl5 =sfenr5 .
* Must be: sfnboy6+ sfngirl6= sfenr6.
* Must be: sfnboy7 +sfngirl7= sfenr7 .


USE ALL.
COMPUTE filter_$=(sfnboy5 +sfngirl5 ~=sfenr5 or sfnboy6+ sfngirl6~= sfenr6 or sfnboy7 + sfngirl7 ~= sfenr7 ).
VARIABLE LABEL filter_$ 'Enrolment sub-sets and totals'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=sf_cas region district school sfclass sfnboy5 to sfenr7
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE=  'Enrolment sub-sets and totals'
  /MISSING=VARIABLE
  /CELLS=COUNT .



***********************************************************************************************************************************
*                                                                                                                                                                  *
*      CHECK FOR NUMBER OF TEACHERS SUB-TOTALS                                                                             *
*                                                                                                                                                                  *
************************************************************************************************************************************

* Teachers sub-sets and totals.
* Must be: sftmale5 +sftfmal5 =sfttot5 .
* Must be: sftmale6+ sftfmal6= sfttot6.
* Must be: sftmale7 +sftfmal7= sfttot7 .

USE ALL.
COMPUTE filter_$=(sftmale5 +sftfmal5 ~=sfttot5 or sftmale6+ sftfmal6~= sfttot6 OR sftmale7 +sftfmal7~= sfttot7).
VARIABLE LABEL filter_$ 'Teachers sub-sets and totals'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=sf_cas region district school sfclass sftmale5 to sfttot7
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE=  'Teachers sub-sets and totals'
  /MISSING=VARIABLE
  /CELLS=COUNT .




***********************************************************************************************************************************
*                                                                                                                                                                  *
*      CHECK FOR NUMBER OF TEACHERS SUB-TOTALS                                                                             *
*                                                                                                                                                                  *
************************************************************************************************************************************

USE ALL.
EXECUTE .

SORT CASES BY
  region (A) district (A) school (A) .

AGGREGATE
  /OUTFILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolForm\temp7.sav'
  /BREAK=region district school  
  /sfpu_sum = SUM(sfpup)
  /sfpG6_mn = mean(sfpupg6) 
  /sfcG6_mn = mean(sfclag6) 
  /N_G6cls=N.

GET 
  FILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolForm\temp7.sav'.



* Sum of all the G6 classes does not much with the reported G6.

USE ALL.
COMPUTE filter_$=(sfpu_sum ~= sfpG6_mn ).
VARIABLE LABEL filter_$ 'Sum of all the G6 pupils does not much with the reported G6'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=region district school sfpu_sum sfpG6_mn 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE=  'Sum of all the G6 classes does not much with the reported G6'
  /MISSING=VARIABLE
  /CELLS=COUNT .




* Count of all the G6 classes does not much with the reported # of G6 classes.

USE ALL.
COMPUTE filter_$=(N_G6cls~= sfcG6_mn ).
VARIABLE LABEL filter_$ 'Count of all the G6 classes does not much with the reported # of G6 classes'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=region district school N_G6cls sfcG6_mn 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE=  'Count of all the G6 classes does not much with the reported # of G6 classes' 
  /MISSING=VARIABLE
  /CELLS=COUNT .


****** END ***************** END ************** END ************** END ******************* END *************************** .