
******************************************************************************************************************************************************
**********                                                                                                                                                  ***********************
**********       CONSISTENCIES BETWEEN SCHOOL FORM & SCHOOL INFORMATION BOOKLET              ***********************
**********                                                                                                                                                   ***********************
**********                                                                                                                                                  ************************
*******************************************************************************************************************************************************
*******************************************************************************************************************************************************

GET
  FILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolInformationBooklet\06_SIBK_XXX_S3_26SEPT2007.SAV'.

COMPUTE sibk_cas = $CASENUM .
VARIABLE LABEL sibk_cas 'School Information Booklet Case Number'.
FORMAT sibk_cas (F8.0).
EXECUTE .

compute idschool=school.
formats idschool (F9.0).



**Total School Enrolment 1****

recode spupboy spupgirl (missing=0).
compute enrtot= spupboy +spupgirl.
formats enrtot (F6.0).



**Total Grade 6 Enrolment****

recode spupboy6  spupgir6 (missing=0).
compute enr6tot= spupboy6 + spupgir6.
formats enr6tot (F5.0).


**Total School Enrolment 2***

recode ssess1p ssess2p ssess3p ssess4p ssess5p (missing=0).
compute shifttot= ssess1p+ ssess2p+ ssess3p +ssess4p+ ssess5p .
formats shifttot (F6.0).



***Total Number of Classes in the School***

recode ssess1c ssess2c ssess3c ssess4c ssess5c (missing=0).
compute cltot= ssess1c +ssess2c +ssess3c+ ssess4c+ ssess5c .
formats cltot (F3.0).
EXECUTE.


sort cases by idschool (a).


save OUTFILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolInformationBooklet\sibktemp.sav' 
/keep sibk_cas idschool  spupboy spupgirl spupboy6 spupgir6 sclass6 ssess1p ssess1c ssess2p  ssess2c ssess3p ssess3c ssess4p ssess4c ssess5p ssess5c 
 enrtot shifttot  cltot enr6tot stchtot1 stchtot2 stchtot3 stchtot4.




****GET SCHOOL FORM DATA***********************

GET 
  FILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolForm\04_SF_XXX_S3_26SEPT2007.SAV'.

COMPUTE sf_cas = $CASENUM .
VARIABLE LABEL sf_cas 'School Form Case Number'.
FORMAT sf_cas (F8.0).
EXECUTE .

compute idschool=school.
formats idschool (F9.0).


sort cases by idschool (a) .

AGGREGATE
  /OUTFILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolForm\sfagg.SAV'
  /BREAK=idschool
  /enrol = MEAN(sfenr7)            
  /class = MEAN(sfclses)           
  /pupg6 = MEAN(sfpupg6)         
  /classg6 = MEAN(sfclag6)       
  /pupg6sum = SUM(sfpup)        
  /tottch=MEAN(sfttot7)             
  /N_BREAK=N.

*********************************************************************************************************
***                                        NOTES                                                                 *********
***                                                                                                                    *********
 ** /enrol = MEAN(sfenr7)---------------> School enrolment 2007                                *********      
 ** /class = MEAN(sfclses)-------------> Number of classes in the school                   *********
 ** /pupg6 = MEAN(sfpupg6)-----------> Total Grade 6 enrolment                               *********       
 ** /classg6 = MEAN(sfclag6)----------> Total Grade 6 classess                                *********       
 ** /pupg6sum = SUM(sfpup)-----------> Total Grade 6 enrolment                               *********         
 ** /tottch=MEAN(sfttot7)----------------> Total number of teachers in the school 2007  **********
 ** /N_BREAK=N----------------------------> Total Grade 6 Classes                                 *********      
***********************************************************************************************************


**MERGING******

GET
  FILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolInformationBooklet\sibktemp.sav' .

MATCH FILES /FILE=*
 /FILE='R:\SACMEQ 3\02 WORKING\07. DATA\CLEANING\CountryData\XXX\SchoolForm\sfagg.sav'
 /BY idschool.
EXECUTE.

FORMAT enrol class pupg6 classg6 pupg6sum tottch (F8.0).
EXE.



* Check agreement on the total enrolment for 2007.

USE ALL.
COMPUTE filter_$=(enrtot  ~= enrol or shifttot~=enrtot  or shifttot~=enrol  ).
VARIABLE LABEL filter_$ 'Agreement on the total enrolment for 2007'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .


SUMMARIZE
  /TABLES=sibk_cas idschool enrtot shifttot enrol 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Agreement on the total enrolment for 2007'
  /MISSING=VARIABLE
  /CELLS=COUNT .


* Check agreement on the G6 enrolment .

USE ALL.
COMPUTE filter_$=(enr6tot ~=  pupg6sum or  pupg6 ~=enr6tot or enr6tot ~= pupg6  ).
VARIABLE LABEL filter_$ 'Agreement on the G6 enrolment'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=sibk_cas idschool enr6tot pupg6 pupg6sum 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Agreement on the G6 enrolment'
  /MISSING=VARIABLE
  /CELLS=COUNT .


* Check agreement on the G6 # of classes.

USE ALL.
COMPUTE filter_$=(sclass6 ~= classg6 or sclass6 ~= n_break or classg6 ~=  n_break).
VARIABLE LABEL filter_$ 'Agreement on the G6 # of classes'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=sibk_cas idschool sclass6 classg6 n_break
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Agreement on the G6 # of classes'
  /MISSING=VARIABLE
  /CELLS=COUNT .


* Check on agreement on the # of teachers. 

USE ALL.
COMPUTE filter_$=(stchtot1 ~= tottch).
VARIABLE LABEL filter_$ 'Agreement on the # of teachers'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

SUMMARIZE
  /TABLES=sibk_cas idschool stchtot1 tottch
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Agreement on the # of teachers'
  /MISSING=VARIABLE
  /CELLS=COUNT .


*******END*************END*********END************** .